@@ -17,7 +17,7 @@
  * along with QCAD.
  */
 
-include("../Help.js");
+include("scripts/Help/Help.js");
 include("AboutCredits.js");
  
 
@@ -106,8 +106,9 @@ About.prototype.initAboutApp = function(textBrowser) {
             + this.head
             + "<body>"
             + "<h1>%1</h1>".arg(this.applicationName)
-            + "<hr/>"
-            + "<table border='0'><tr>"
+            + "<hr/>";
+            html +=
+              "<table border='0'><tr>"
             + "<td><b>" + qsTr("Version:") + "</b> </td><td>%1 %2</td>"
               .arg(versionComplete)
               .arg(version.length>0 ? "("+version+")" : "")
@@ -119,14 +120,19 @@ About.prototype.initAboutApp = function(textBrowser) {
             + "<td><b>" + qsTr("Revision:") + "</b> </td><td>%1</td>".arg(RSettings.getRevisionString().left(7))
             + "</tr><tr>"
             + "<td><b>" + qsTr("Qt Version:") + "</b> </td><td>%1</td>".arg(RSettings.getQtVersionString())
-            + "</tr><tr>";
-            if (RS.getBuildCpuArchitecture().length!==0) {
-                html += "<td><b>" + qsTr("Architecture:") + "</b> </td><td>%1</td>".arg(RS.getBuildCpuArchitecture())
-                + "</tr><tr>";
+            + "</tr>";
+            var bca = RS.getBuildCpuArchitecture();
+            if (bca.length!==0) {
+                html += "<tr><td><b>" + qsTr("Architecture:") + "</b> </td><td>%1</td>".arg(bca) + "</tr>";
             }
-            html += "<td><b>" + qsTr("Compiler:") + "</b> </td><td>%1</td>".arg(RSettings.getCompilerVersion())
-            + "</tr></table>"
-            + "<hr/>"
+            html += "<tr><td><b>" + qsTr("Compiler:") + "</b> </td><td>%1</td>".arg(RSettings.getCompilerVersion()) + "</tr>";
+            var lk = RSettings.getStringValue("License/LicenseKey", "");
+            if (lk.length>0) {
+                html += "<tr><td><b>" + qsTr("License Key:") + "</b> </td><td>%1</td>".arg(lk) + "</tr>";
+            }
+            html += "</table>";
+
+            html += "<hr/>"
             + "<p>" + qsTr("%1 is an application for computer-aided design (CAD).").arg(this.applicationName) + "</p>"
             + "<p/>";
 
@@ -138,7 +144,7 @@ About.prototype.initAboutApp = function(textBrowser) {
                       + "" + qsTr("This means that everyone can <a href='%1'>get involved</a>!").arg("http://www.qcad.org/contribute") + "</p>";
             }
 
-            html += "<p>" + qsTr("Plugins and script add-ons are subject to their respective license (see 'Plugins' tab).") + "</p>"
+            html += "<p>" + qsTr("Plugins and script add-ons are subject to their respective license (see \"Plugins\" tab).") + "</p>"
             + "<p/>"
             + "<p>" + qsTr("All brand or product names are trademarks or registered trademarks of their respective holders.") + "</p>"
             + "<p/>"
@@ -165,10 +171,7 @@ About.prototype.initAboutPlugins = function(textBrowser) {
         html += qsTr("No plugins found.");
     }
     else {
-        var namePostfixesSlash = [];
-        var namePostfixesSpace = [];
-        var nameOverrides = [];
-        var versionOverrides = [];
+        var maxPri = undefined;
         for (var i=0; i<numPlugins; i++) {
             html += "<table border='0' width='100%'>";
 
@@ -176,33 +179,41 @@ About.prototype.initAboutPlugins = function(textBrowser) {
 
             var pluginInfo = RPluginLoader.getPluginInfo(i);
 
+            // override priority:
+            var pri = pluginInfo.get("OverridePriority");
+            if (!isNull(pri)) {
+                pri = parseInt(pri);
+            }
+            else {
+                // default to lowest priority:
+                pri = 0;
+            }
+
+            //qDebug("ID:", pluginInfo.get("ID"));
+            //qDebug("pri:", pri);
+
             // plugin about info:
             text = pluginInfo.get("Name", qsTr("No information available"));
             html += this.getTableRow(qsTr("Plugin:"), "<b>" + Qt.escape(text) + "</b>", false);
 
-            text = pluginInfo.get("NamePostfix");
-            if (!isNull(text)) {
-                if (text.startsWith("/")) {
-                    namePostfixesSlash.push(text);
+            // overrides:
+            if (isNull(maxPri) || pri>maxPri) {
+                maxPri = pri;
+
+                text = pluginInfo.get("NameOverride");
+                if (!isNull(text)) {
+                    this.applicationName = text;
                 }
-                else {
-                    namePostfixesSpace.push(text);
+
+                text = pluginInfo.get("VersionOverride");
+                if (!isNull(text)) {
+                    this.version = text;
                 }
-            }
 
-            text = pluginInfo.get("NameOverride");
-            if (!isNull(text)) {
-                nameOverrides.push(text);
-            }
-
-            text = pluginInfo.get("VersionOverride");
-            if (!isNull(text)) {
-                versionOverrides.push(text);
-            }
-
-            text = pluginInfo.get("IconOverride");
-            if (!isNull(text)) {
-                this.iconFile = text;
+                text = pluginInfo.get("IconOverride");
+                if (!isNull(text)) {
+                    this.iconFile = text;
+                }
             }
 
             // ID:
@@ -247,12 +258,7 @@ About.prototype.initAboutPlugins = function(textBrowser) {
                         var fixedUrl = url.toString();
                         fixedUrl = fixedUrl.replace("QUrl( \"", "");
                         fixedUrl = fixedUrl.replace("\" )", "");
-                        html += this.getTableRow(
-                            qsTr("Internet:"),
-                            "<a href='%2'>%3</a>"
-                                .arg(fixedUrl).arg(fixedUrl),
-                            false
-                        );
+                        html += this.getTableRow(qsTr("Internet:"), "<a href='%2'>%3</a>" .arg(fixedUrl).arg(fixedUrl), false);
                     }
                 }
             }
@@ -289,26 +295,6 @@ About.prototype.initAboutPlugins = function(textBrowser) {
             html += "</table>";
             html += "<hr/>";
         }
-
-        // name override:
-        if (nameOverrides.length!==0) {
-            var a = nameOverrides.sort( function (a, b) { return b.length - a.length; });
-            this.applicationName = a[0];
-        }
-        else {
-            // add name postfixes:
-
-            // e.g. "/XYZ" for "MyApp/XYZ":
-            namePostfixesSlash.sort();
-            // e.g. "Incredible Edition" for "MyApp Incredible Edition":
-            namePostfixesSpace.sort();
-            this.applicationName = qApp.applicationName + namePostfixesSlash.join("") + namePostfixesSpace.join("");
-        }
-
-        // version override:
-        if (versionOverrides.length!==0) {
-            this.version = versionOverrides[0];
-        }
     }
 
     if (this.applicationName==="QCAD") {
@@ -442,6 +428,10 @@ About.prototype.initAboutSystem = function(textEdit) {
             .arg(RSettings.getRevisionVersion())
             .arg(RSettings.getBuildVersion());
     }
+    var lk = RSettings.getStringValue("License/LicenseKey", "");
+    if (lk.length>0) {
+        text += "\nLicense Key: " + lk;
+    }
     text += "\nDate: " + RSettings.getReleaseDate();
     text += "\nQt version: " + RSettings.getQtVersionString();
     text += "\nCompiler version: " + RSettings.getCompilerVersion();
